==> developer-center-api-3.3.31-sources.jar: cn/com/duiba/developer/center/api/domain/dto/forum/ForumAnnouncementDto.java <==
package cn.com.duiba.developer.center.api.domain.dto.forum;

import cn.com.duiba.developer.center.api.domain.enums.forum.AnnouncementStatusEnum;
import cn.com.duiba.developer.center.api.domain.enums.forum.AnnouncementTypeEnum;

import java.io.Serializable;
import java.util.Date;

/**
 * @Auther: linjianhui
 * @Date: 2018/11/15 19:00
 * @Description: 后台商家社区公告
 */
public class ForumAnnouncementDto implements Serializable{

    private static final long serialVersionUID = 7449525216968744819L;

    private Long id;

    private Long adminId;

    private String title;

    private String summary;

    private String headImg;

    private String content;

    private AnnouncementTypeEnum type;

    private AnnouncementStatusEnum status;

    private Date gmtCreate;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAdminId() {
        return adminId;
    }

    public void setAdminId(Long adminId) {
        this.adminId = adminId;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getSummary() {
        return summary;
    }

    public void setSummary(String summary) {
        this.summary = summary;
    }

    public String getHeadImg() {
        return headImg;
    }

    public void setHeadImg(String headImg) {
        this.headImg = headImg;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public AnnouncementTypeEnum getType() {
        return type;
    }

    public void setType(AnnouncementTypeEnum type) {
        this.type = type;
    }

    public AnnouncementStatusEnum getStatus() {
        return status;
    }

    public void setStatus(AnnouncementStatusEnum status) {
        this.status = status;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }
}

==> developer-center-api-3.5.59-sources.jar: cn/com/duiba/developer/center/api/domain/dto/forum/ForumAnnouncementDto.java <==
package cn.com.duiba.developer.center.api.domain.dto.forum;

import cn.com.duiba.developer.center.api.domain.enums.forum.AnnouncementStatusEnum;
import cn.com.duiba.developer.center.api.domain.enums.forum.AnnouncementTypeEnum;

import java.io.Serializable;
import java.util.Date;

/**
 * @Auther: linjianhui
 * @Date: 2018/11/15 19:00
 * @Description: 后台商家社区公告
 */
public class ForumAnnouncementDto implements Serializable{

    private static final long serialVersionUID = 7449525216968744819L;

    private Long id;

    private Long adminId;

    private String title;

    private String summary;

    private String headImg;

    private String content;

    private String nickName;

    private Date promotionStartTime;

    private Date promotionEndTime;

    private AnnouncementTypeEnum type;

    private AnnouncementStatusEnum status;

    private Date gmtCreate;

    private Date gmtModified;

    private Date publishTime;

    //排序时间，目前针对新闻资讯类在兑吧官网的展现排序 by lufeng
    private Date orderTime;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAdminId() {
        return adminId;
    }

    public void setAdminId(Long adminId) {
        this.adminId = adminId;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getSummary() {
        return summary;
    }

    public void setSummary(String summary) {
        this.summary = summary;
    }

    public String getHeadImg() {
        return headImg;
    }

    public void setHeadImg(String headImg) {
        this.headImg = headImg;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public AnnouncementTypeEnum getType() {
        return type;
    }

    public void setType(AnnouncementTypeEnum type) {
        this.type = type;
    }

    public AnnouncementStatusEnum getStatus() {
        return status;
    }

    public void setStatus(AnnouncementStatusEnum status) {
        this.status = status;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getPublishTime() {
        return publishTime;
    }

    public void setPublishTime(Date publishTime) {
        this.publishTime = publishTime;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getPromotionStartTime() {
        return promotionStartTime;
    }

    public void setPromotionStartTime(Date promotionStartTime) {
        this.promotionStartTime = promotionStartTime;
    }

    public Date getPromotionEndTime() {
        return promotionEndTime;
    }

    public void setPromotionEndTime(Date promotionEndTime) {
        this.promotionEndTime = promotionEndTime;
    }

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public Date getOrderTime() {
        return orderTime;
    }

    public void setOrderTime(Date orderTime) {
        this.orderTime = orderTime;
    }
}
